
%**************************************************************************
% Programm nlms_demo_main
%
% Author:              Gerhard Schmidt, CAU Digital Signal Processing and
%                      System Theory
% Date of generation:  December, 26, 2005
% Project:             predictor_demo
%
% 
% Input: 
%
% Output:               ---
%
%**************************************************************************


%******************************************************************
% Set path to subdirectories
%******************************************************************
 
addpath([pwd,'/subfunctions']);
addpath([pwd,'/images']);
addpath([pwd,'/signals']);

%******************************************************************
% Main data_struct
%******************************************************************

dim.main_fig.orig_x                        =   12;
dim.main_fig.orig_y                        =   45;
dim.main_fig.width                         = 1000;
dim.main_fig.height                        =  670;
dim.main_fig.space_lr                      =   30; 
dim.main_fig.space_tb                      =   30;
dim.main_fig.af_logo.width                 =  342;
dim.main_fig.af_logo.height                =   48;
dim.main_fig.low_frame.height              =   48;
dim.main_fig.low_frame.button.width        =  140;
dim.main_fig.low_frame.button.height       =   32;
dim.main_fig.low_frame.button.delta_w      =   30;
dim.main_fig.low_frame.checkbox.width      =  100;
dim.main_fig.left_frame.width.small        =  200;
dim.main_fig.left_frame.width.large        =  700;
dim.main_fig.left_frame.space_lr           =   10;
dim.main_fig.left_frame.space_lr_sm        =   10;
dim.main_fig.left_frame.space_tb           =   10;
dim.main_fig.left_frame.space_tb_sm        =    2;
dim.main_fig.left_frame.button.height      =   25;
dim.main_fig.left_frame.button.text_offset =    4;
dim.main_fig.axes.space_left               =   60;
dim.main_fig.axes.space_bottom             =   30;
dim.main_fig.axes.space_delta              =   16;

fonts.normal.size      =  9;
fonts.upper_frame.size = 12;
fonts.small.size       =  9;

[main_data.signals.x main_data.f_s] = wavread('speech_female_16000.wav');
main_data.predictor.length          =   12;
main_data.predictor.frameshift      =   64;
main_data.predictor.n_ana           =  512;
main_data.predictor.h_ana           = hanning(main_data.predictor.n_ana);
main_data.predictor.n_fft           = 1024;
main_data.predictor.k_frame         = ceil(main_data.predictor.n_ana / (2*main_data.predictor.frameshift));
main_data.predictor.k_dir           =    1;
main_data.predictor.h               = [1; zeros(main_data.predictor.length,1)];
main_data.predictor.gain            =    1;
main_data.predictor.x_ana           = zeros(main_data.predictor.n_ana,1);
main_data.predictor.x_p             = zeros(main_data.predictor.length+1,1);
main_data.predictor.error_vec       = zeros(main_data.predictor.frameshift,1);

main_data.axes_top.plot_method            = 'imp_res';
main_data.axes_top.plot_handle_1          = 0;
main_data.axes_top.plot_handle_2          = 0;
main_data.axes_top.index                  = 0;
main_data.axes_top.plot_method_changed    = 0;
main_data.axes_bottom.plot_method         = 't_ana';
main_data.axes_bottom.plot_handle_1       = 0;
main_data.axes_bottom.plot_handle_2       = 0;
main_data.axes_bottom.index               = 0;
main_data.axes_bottom.plot_method_changed = 0;

main_data.sim_active = 0;
main_data.auto_mode  = 1;

%******************************************************************
% User interface
%******************************************************************

load predictor_demo_main;

a = figure('Units','pixels', ...
           'Color',[0.85 0.85 0.85], ...
           'Colormap',mat0, ...
           'Name','Adaptive Filters - Demo Predictor', ...         
	       'NumberTitle','off', ...
           'PointerShapeCData',mat1, ...
	       'Position',[dim.main_fig.orig_x dim.main_fig.orig_y dim.main_fig.width dim.main_fig.height], ...
           'UserData',main_data, ...
           'Tag','demo_predictor_main_fig');                  
      
%******************************************************************
% Title frame
%******************************************************************       
          
b = axes('Parent',a, ...
         'Units','pixels', ...
	     'Box','on', ...
	     'CameraUpVector',[0 1 0], ...
	     'Color',[1 1 1], ...
         'ColorOrder',mat2, ... 
         'CreateFcn','image(logo_adaptive_filters); axis tight; set(gca,''XTick'',[],''YTick'',[]);', ...
	     'Position',[dim.main_fig.space_lr dim.main_fig.height-dim.main_fig.space_tb-dim.main_fig.af_logo.height dim.main_fig.af_logo.width dim.main_fig.af_logo.height], ...
	     'Tag','demo_predictor_axes_logo');

b = uicontrol('Parent',a, ...                       
	          'Units','pixels', ...                   
	          'BackgroundColor',[0.9 0.9 0.9], ...   
              'Position',[dim.main_fig.af_logo.width+(2*dim.main_fig.space_lr) dim.main_fig.height-dim.main_fig.space_tb-dim.main_fig.af_logo.height dim.main_fig.width-(3*dim.main_fig.space_lr)-dim.main_fig.af_logo.width dim.main_fig.af_logo.height], ...
	          'Style','frame', ...
              'Tag','demo_predictor_uppper_fraime'); 
                                                      
b = uicontrol('Parent',a, ...                       
              'Units','pixels', ...              
              'BackgroundColor',[0.9 0.9 0.9], ...   
	          'HorizontalAlignment','center', ...
              'FontWeight','bold', ...
              'FontSize',fonts.upper_frame.size, ...
	          'Position',[dim.main_fig.af_logo.width+(2*dim.main_fig.space_lr)+5 dim.main_fig.height-dim.main_fig.space_tb-dim.main_fig.af_logo.height+12 dim.main_fig.width-(3*dim.main_fig.space_lr)-dim.main_fig.af_logo.width-10 20], ...
	          'String','Demo - Predictor', ...
	          'Style','text');  
                   
%******************************************************************
% Left frame (visible)
%******************************************************************    
                        
b = uicontrol('Parent',a, ...                        
	          'Units','pixels', ...              
	          'BackgroundColor',[0.9 0.9 0.9], ...   
              'Position',[dim.main_fig.space_lr (2*dim.main_fig.space_tb)+dim.main_fig.af_logo.height dim.main_fig.left_frame.width.small dim.main_fig.height-(4*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-dim.main_fig.low_frame.height ], ...
	          'Style','frame', ...
              'Tag','demo_predictor_main_left_frame');           
                    
b = uicontrol('Parent',a, ...                        
	          'Units','pixels', ...              
              'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.space_lr dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-dim.main_fig.left_frame.space_tb-dim.main_fig.left_frame.button.height round((dim.main_fig.left_frame.width.small-(3*dim.main_fig.left_frame.space_lr))/2) dim.main_fig.left_frame.button.height], ...  
              'Callback','dp_reduce_frame_left(dim)', ...             
	          'String','<<', ...
              'TooltipString','Hides a picture that shows the structure of the algorithm.',...
              'FontWeight','bold', ...   
              'Tag','demo_predictor_reduce_left_frame');

b = uicontrol('Parent',a, ...                        
	          'Units','pixels', ...              
              'Position',[dim.main_fig.space_lr+round((dim.main_fig.left_frame.width.small+dim.main_fig.left_frame.space_lr)/2) dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-dim.main_fig.left_frame.space_tb-dim.main_fig.left_frame.button.height round((dim.main_fig.left_frame.width.small-(3*dim.main_fig.left_frame.space_lr))/2) dim.main_fig.left_frame.button.height], ...  
              'Callback','dp_enlarge_frame_left(dim);', ...             
	          'String','>>', ...
              'TooltipString','Shows a picture that depicts the structure of the algorithm.',...
              'FontWeight','bold', ...   
              'Tag','demo_predictor_enlarge_left_frame');          

b = uicontrol('Parent',a, ...                        
	          'Units','pixels', ...              
	          'BackgroundColor',[0.95 0.95 0.95], ...   
              'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.space_lr dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-(4*dim.main_fig.left_frame.space_tb)-(4*dim.main_fig.left_frame.button.height) dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr) (3*dim.main_fig.left_frame.button.height)+(3*dim.main_fig.left_frame.space_tb_sm)+dim.main_fig.left_frame.space_tb], ...
	          'Style','frame', ...
              'Tag','demo_predictor_main_left_frame_visualizations');            
              
b = uicontrol('Parent',a, ...                       
              'Units','pixels', ...              
              'BackgroundColor',[0.95 0.95 0.95], ...   
	          'HorizontalAlignment','left', ...
              'FontWeight','bold', ...
              'FontSize',fonts.normal.size, ...
	          'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.space_lr+dim.main_fig.left_frame.space_lr_sm dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-(3*dim.main_fig.left_frame.space_tb)-(2*dim.main_fig.left_frame.button.height) dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr)-(2*dim.main_fig.left_frame.space_lr_sm) dim.main_fig.left_frame.button.height-dim.main_fig.left_frame.button.text_offset], ...
	          'String','Visualizations:', ...
	          'Tag','demo_predictor_main_left_frame_text_visualization', ...
              'Style','text');            
                           
b = uicontrol('Parent',a, ...               
              'Units','pixels', ...                                
              'BackgroundColor',[1 1 1], ...    
              'String',{'Plot 1: Freq. res','Plot 1: Impulse res.','Plot 1: Pred. error sig.'}, ...
              'FontWeight','bold', ...
              'Value',2, ...
              'HorizontalAlignment','right', ...
              'Callback','x=get(gco,''Value''); main_data = get(gcf,''UserData''); if (x == 1), main_data.axes_top.plot_method = ''spec_env''; else, if (x == 2), main_data.axes_top.plot_method  = ''imp_res''; else, main_data.axes_top.plot_method  = ''pred_err'';  end; end; main_data.axes_top.plot_method_changed = 1; set(gcf,''UserData'',main_data);', ...
	          'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.space_lr+dim.main_fig.left_frame.space_lr_sm dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-(3*dim.main_fig.left_frame.space_tb)-dim.main_fig.left_frame.space_tb_sm-(3*dim.main_fig.left_frame.button.height) dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr)-(2*dim.main_fig.left_frame.space_lr_sm) dim.main_fig.left_frame.button.height], ...
              'TooltipString','Selects the type of visualisation showed in the upper diagram.',...
              'Style','popupmenu', ...  
              'Tag','demp_predictor_main_left_frame_plot_axes_top');

b = uicontrol('Parent',a, ...               
              'Units','pixels', ...                                
              'BackgroundColor',[1 1 1], ...    
              'String',{'Plot 2: Spectrogram','Plot 2: Signal (time)'}, ...
              'FontWeight','bold', ...
              'Value',2, ...
              'HorizontalAlignment','right', ...
              'Callback','x=get(gco,''Value''); main_data = get(gcf,''UserData''); if (x==1), main_data.axes_bottom.plot_method = ''tf_ana''; else, main_data.axes_bottom.plot_method = ''t_ana'';end; main_data.axes_bottom.plot_method_changed = 1; set(gcf,''UserData'',main_data); drawnow; dp_plot_init(2);', ...
	          'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.space_lr+dim.main_fig.left_frame.space_lr_sm dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-(3*dim.main_fig.left_frame.space_tb)-(2*dim.main_fig.left_frame.space_tb_sm)-(4*dim.main_fig.left_frame.button.height) dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr)-(2*dim.main_fig.left_frame.space_lr_sm) dim.main_fig.left_frame.button.height], ...
              'TooltipString','Selects the type of visualisation showed in the lower diagram.',...
              'Style','popupmenu', ...  
              'Tag','demp_predictor_main_left_frame_plot_axes_bottom');          

b = uicontrol('Parent',a, ...                        
	          'Units','pixels', ...              
	          'BackgroundColor',[0.95 0.95 0.95], ...   
              'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.space_lr dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-(6*dim.main_fig.left_frame.space_tb)-(1*dim.main_fig.left_frame.space_tb_sm)-(6*dim.main_fig.left_frame.button.height) dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr) (2*dim.main_fig.left_frame.button.height)+dim.main_fig.left_frame.space_tb+(1*dim.main_fig.left_frame.space_tb_sm)], ...
	          'Style','frame', ...
              'Tag','demo_predictor_main_left_frame_visualizations');           
              
b = uicontrol('Parent',a, ...                       
              'Units','pixels', ...              
              'BackgroundColor',[0.95 0.95 0.95], ...   
	          'HorizontalAlignment','left', ...
              'FontWeight','bold', ...
              'FontSize',fonts.normal.size, ...
	          'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.space_lr+dim.main_fig.left_frame.space_lr_sm dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-(5*dim.main_fig.left_frame.space_tb)-(5*dim.main_fig.left_frame.button.height)-(2*dim.main_fig.left_frame.space_tb_sm) dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr)-(2*dim.main_fig.left_frame.space_lr_sm) dim.main_fig.left_frame.button.height-dim.main_fig.left_frame.button.text_offset], ...
	          'String','Signals:', ...
	          'Tag','demo_predictor_main_left_frame_text_signals', ...
              'Style','text');    
          
b = uicontrol('Parent',a, ...                       
              'Units','pixels', ...              
              'BackgroundColor',[0.95 0.95 0.95], ...   
	          'HorizontalAlignment','left', ...
              'FontWeight','bold', ...
              'FontSize',fonts.small.size, ...
	          'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.space_lr+dim.main_fig.left_frame.space_lr_sm dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-(5*dim.main_fig.left_frame.space_tb)-(6*dim.main_fig.left_frame.button.height)-(2*dim.main_fig.left_frame.space_tb_sm) round((dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr)-(2*dim.main_fig.left_frame.space_lr_sm))/2) dim.main_fig.left_frame.button.height-dim.main_fig.left_frame.button.text_offset], ...
	          'String','Input:', ...
	          'Tag','demo_predictor_main_left_frame_text_signals_excitation_left', ...
              'Style','text');
          
b = uicontrol('Parent',a, ...                       
              'Units','pixels', ...              
              'BackgroundColor',[0.95 0.95 0.95], ...   
	          'HorizontalAlignment','right', ...
              'FontWeight','bold', ...
              'FontSize',fonts.small.size, ...
	          'Position',[dim.main_fig.space_lr+round(dim.main_fig.left_frame.width.small/2)  dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-(5*dim.main_fig.left_frame.space_tb)-(6*dim.main_fig.left_frame.button.height)-(2*dim.main_fig.left_frame.space_tb_sm) round((dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr)-(2*dim.main_fig.left_frame.space_lr_sm))/2) dim.main_fig.left_frame.button.height-dim.main_fig.left_frame.button.text_offset], ...
	          'String','speech', ...
	          'Tag','demo_predictor_main_left_frame_text_signals_excitation_right', ...
              'Style','text');                           
                                                          
b = uicontrol('Parent',a, ...                        
	          'Units','pixels', ...              
	          'BackgroundColor',[0.95 0.95 0.95], ...   
              'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.space_lr dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-(9*dim.main_fig.left_frame.space_tb)-(2*dim.main_fig.left_frame.space_tb_sm)-(8*dim.main_fig.left_frame.button.height) dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr) (2*dim.main_fig.left_frame.button.height)+(2*dim.main_fig.left_frame.space_tb)], ...
	          'Style','frame', ...
              'Tag','demo_predictor_main_left_frame_control_para');   
          
b = uicontrol('Parent',a, ...                       
              'Units','pixels', ...              
              'BackgroundColor',[0.95 0.95 0.95], ...   
	          'HorizontalAlignment','left', ...
              'FontWeight','bold', ...
              'FontSize',fonts.normal.size, ...
	          'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.space_lr+dim.main_fig.left_frame.space_lr_sm dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-(7*dim.main_fig.left_frame.space_tb)-(7*dim.main_fig.left_frame.button.height)-(5*dim.main_fig.left_frame.space_tb_sm) dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr)-(2*dim.main_fig.left_frame.space_lr_sm) dim.main_fig.left_frame.button.height-dim.main_fig.left_frame.button.text_offset], ...
	          'String','Filter parameters:', ...
	          'Tag','demo_predictor_main_left_frame_text_control_parameters', ...
              'Style','text');            

b = uicontrol('Parent',a, ...                       
              'Units','pixels', ...              
              'BackgroundColor',[0.95 0.95 0.95], ...   
	          'HorizontalAlignment','left', ...
              'FontWeight','bold', ...
              'FontSize',fonts.small.size, ...
	          'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.space_lr+dim.main_fig.left_frame.space_lr_sm dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-(7*dim.main_fig.left_frame.space_tb)-(8*dim.main_fig.left_frame.button.height)-(5*dim.main_fig.left_frame.space_tb_sm) round((dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr)-(2*dim.main_fig.left_frame.space_lr_sm))/2) dim.main_fig.left_frame.button.height-dim.main_fig.left_frame.button.text_offset], ...
	          'String','Order:', ...
	          'Tag','demo_predictor_main_left_frame_text_para_order_left', ...
              'Style','text');    
          
b = uicontrol('Parent',a, ...                       
              'Units','pixels', ...              
              'BackgroundColor',[1 1 1], ...   
	          'HorizontalAlignment','right', ...
              'FontWeight','bold', ...
              'FontSize',fonts.small.size, ...
	          'Position',[dim.main_fig.space_lr+round(dim.main_fig.left_frame.width.small/2)  dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-(7*dim.main_fig.left_frame.space_tb)-(8*dim.main_fig.left_frame.button.height)-(5*dim.main_fig.left_frame.space_tb_sm) round((dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr)-(2*dim.main_fig.left_frame.space_lr_sm))/2) dim.main_fig.left_frame.button.height-dim.main_fig.left_frame.button.text_offset], ...
	          'String',num2str(main_data.predictor.length), ...
              'Callback','main_data = get(gcf,''UserData''); main_data.predictor.length = str2num(get(gco,''String'')); main_data.axes_top.plot_method_changed = 1; main_data.predictor.h = zeros(main_data.predictor.length+1,1); main_data.predictor.h(1) = 1; main_data.predictor.x_p = zeros(main_data.predictor.length+1,1); set(gcf,''UserData'',main_data); if (strcmp(main_data.axes_top.plot_method,''imp_res'')||(strcmp(main_data.axes_top.plot_method,''pred_err''))); dp_plot_init(1); end; drawnow;', ...
	          'TooltipString','Sets the order of the predictor error filters',...
              'Tag','demo_predictor_main_left_frame_edit_para_order_right', ...
              'Style','edit');           

b = uicontrol('Parent',a, ...                        
	          'Units','pixels', ...              
              'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.space_lr (2*dim.main_fig.space_tb)+dim.main_fig.af_logo.height+dim.main_fig.left_frame.space_lr dim.main_fig.left_frame.width.small-(2*dim.main_fig.left_frame.space_lr) dim.main_fig.low_frame.button.height], ...  
              'Callback','dp_play_input_signal;', ...             
	          'String','Play input signal', ...
              'FontWeight','bold', ... 
              'TooltipString','Play the input signal!',...
              'Tag','demo_predictor_button_play');           
          
%******************************************************************
% Left frame (hidden)
%******************************************************************              
 
b = axes('Parent',a, ...
         'Units','pixels', ...
	     'Box','on', ...
         'Visible','off', ...
	     'CameraUpVector',[0 1 0], ...
	     'Color',[1 1 1], ...
         'ColorOrder',mat2, ... 
         'CreateFcn','set(gca,''XTick'',[],''YTick'',[]);', ...         
	     'Position',[2*dim.main_fig.space_lr+dim.main_fig.left_frame.width.small  (2*dim.main_fig.space_tb)+dim.main_fig.af_logo.height 1 dim.main_fig.height-(4*dim.main_fig.space_tb)-(2*dim.main_fig.af_logo.height)], ...
	     'Tag','demo_predictor_axes_hidden'); 

%******************************************************************
% Main axes (top)
%******************************************************************              
          
b = axes('Parent',a, ...
         'Units','pixels', ...
	     'Box','on', ...
	     'CameraUpVector',[0 1 0], ...
	     'Color',[1 1 1], ...
         'ColorOrder',mat2, ...     
	     'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.width.small+dim.main_fig.axes.space_left round(dim.main_fig.height/2)+dim.main_fig.axes.space_bottom+round(dim.main_fig.axes.space_delta/2)  dim.main_fig.width-(2*dim.main_fig.space_lr)-dim.main_fig.left_frame.width.small-dim.main_fig.axes.space_left dim.main_fig.height-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-round(dim.main_fig.height/2)-dim.main_fig.axes.space_bottom-round(dim.main_fig.axes.space_delta/2)], ...
	     'Tag','demo_predictor_axes_top');              

dp_plot_init(1);     
                  
%******************************************************************
% Main axes (bottom)
%******************************************************************     
     
b = axes('Parent',a, ...
         'Units','pixels', ...
	     'Box','on', ...
	     'CameraUpVector',[0 1 0], ...
	     'Color',[1 1 1], ...
         'ColorOrder',mat2, ...      
	     'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.width.small+dim.main_fig.axes.space_left (2*dim.main_fig.space_tb)+dim.main_fig.low_frame.height+dim.main_fig.axes.space_bottom  dim.main_fig.width-(2*dim.main_fig.space_lr)-dim.main_fig.left_frame.width.small-dim.main_fig.axes.space_left round(dim.main_fig.height/2)-(2*dim.main_fig.space_tb)-dim.main_fig.af_logo.height-dim.main_fig.axes.space_bottom-round(dim.main_fig.axes.space_delta/2)], ...
	     'Tag','demo_predictor_axes_bottom');                                     

dp_plot_init(2);    
         
%******************************************************************
% Lower frame
%******************************************************************    
                        
b = uicontrol('Parent',a, ...                        
	          'Units','pixels', ...              
	          'BackgroundColor',[0.9 0.9 0.9], ...   
              'Position',[dim.main_fig.space_lr dim.main_fig.space_tb dim.main_fig.width-(2*dim.main_fig.space_lr) dim.main_fig.low_frame.height], ...
	          'Style','frame', ...
              'Tag','demo_predictor_lower_frame');           
          
b = uicontrol('Parent',a, ...                        
	          'Units','pixels', ...              
              'Position',[dim.main_fig.width-dim.main_fig.left_frame.space_lr-dim.main_fig.low_frame.button.delta_w-dim.main_fig.low_frame.button.width dim.main_fig.space_tb+round((dim.main_fig.low_frame.height-dim.main_fig.low_frame.button.height)/2) dim.main_fig.low_frame.button.width dim.main_fig.low_frame.button.height], ...  
              'Callback','q_dlg = questdlg(''Do you really want to close the application?'',''Adaptive Filters - Demo Predictor'',''Yes'',''No'',''Cancel'',''Yes''); if strcmp(q_dlg,''Yes''),close(gcf);end;', ...             
	          'String','Close', ...
              'FontWeight','bold', ... 
              'TooltipString','Click here to close the application!',...
              'Tag','demo_predictor_button_close');      
                                              
b = uicontrol('Parent',a, ...
	          'Units','pixels', ...
              'Position',[dim.main_fig.space_lr+dim.main_fig.left_frame.space_lr dim.main_fig.space_tb+round((dim.main_fig.low_frame.height-dim.main_fig.low_frame.button.height)/2) dim.main_fig.low_frame.button.width dim.main_fig.low_frame.button.height], ...
              'Callback','main_data = get(gcf,''UserData''); main_data.sim_active = 1; main_data.predictor.k_dir = -1; main_data.auto_mode = 1;  set(gcf,''UserData'',main_data); drawnow; dp_start_sim;', ...
	          'String','Backwards (auto)', ...
              'FontWeight','bold', ...     
              'TooltipString','Computes automatically the next predictor coefficients when going continiously backwards in time.',...
              'Tag','demo_predictor_button_step_negative_auto');  
          
b = uicontrol('Parent',a, ...
	          'Units','pixels', ...
              'Position',[dim.main_fig.space_lr+2*dim.main_fig.left_frame.space_lr+dim.main_fig.low_frame.button.width dim.main_fig.space_tb+round((dim.main_fig.low_frame.height-dim.main_fig.low_frame.button.height)/2) dim.main_fig.low_frame.button.width dim.main_fig.low_frame.button.height], ...
              'Callback','main_data = get(gcf,''UserData''); main_data.sim_active = 1; main_data.predictor.k_dir = -1; main_data.auto_mode = 0;  set(gcf,''UserData'',main_data); drawnow; dp_start_sim;', ...
	          'String','Backwards (step)', ...
              'FontWeight','bold', ...     
              'TooltipString','Computes the next frame (negative temporal direction)!',...
              'Tag','demo_predictor_button_step_negative_step');          
          
b = uicontrol('Parent',a, ...
	          'Units','pixels', ...
              'Position',[dim.main_fig.space_lr+3*dim.main_fig.left_frame.space_lr+2*dim.main_fig.low_frame.button.width dim.main_fig.space_tb+round((dim.main_fig.low_frame.height-dim.main_fig.low_frame.button.height)/2) dim.main_fig.low_frame.button.width dim.main_fig.low_frame.button.height], ...
              'Callback','main_data = get(gcf,''UserData''); main_data.sim_active = 0;set(gcf,''UserData'',main_data); drawnow;', ...
	          'String','Stop', ...
              'FontWeight','bold', ...     
              'TooltipString','Stops all computations!',...
              'Tag','demo_predictor_button_stop');    

b = uicontrol('Parent',a, ...
	          'Units','pixels', ...
              'Position',[dim.main_fig.space_lr+4*dim.main_fig.left_frame.space_lr+3*dim.main_fig.low_frame.button.width dim.main_fig.space_tb+round((dim.main_fig.low_frame.height-dim.main_fig.low_frame.button.height)/2) dim.main_fig.low_frame.button.width dim.main_fig.low_frame.button.height], ...
              'Callback','main_data = get(gcf,''UserData''); main_data.sim_active = 1; main_data.predictor.k_dir = 1; main_data.auto_mode = 0;  set(gcf,''UserData'',main_data); drawnow; dp_start_sim;', ...
	          'String','Forwards (step)', ...
              'FontWeight','bold', ...     
              'TooltipString','Computes the next frame (positive temporal direction)!',...
              'Tag','demo_predictor_button_step_positive_step');  
          
b = uicontrol('Parent',a, ...
	          'Units','pixels', ...
              'Position',[dim.main_fig.space_lr+5*dim.main_fig.left_frame.space_lr+4*dim.main_fig.low_frame.button.width dim.main_fig.space_tb+round((dim.main_fig.low_frame.height-dim.main_fig.low_frame.button.height)/2) dim.main_fig.low_frame.button.width dim.main_fig.low_frame.button.height], ...
              'Callback','main_data = get(gcf,''UserData''); main_data.sim_active = 1; main_data.predictor.k_dir = 1; main_data.auto_mode = 1;  set(gcf,''UserData'',main_data); drawnow; dp_start_sim;', ...
	          'String','Forwards (auto)', ...
              'FontWeight','bold', ...     
              'TooltipString','Computes continiously the next frames (positive temporal direction)!',...
              'Tag','demo_predictor_button_step_positive_auto');           
                               
                  
% %******************************************************************
% % Allow resizing of the figure
% %******************************************************************          
%              
% ui_cons = findobj('Parent',a);
% for n = 1:length(ui_cons)
%     set(ui_cons(n),'Units','Normalized');
% end;
%           