function dp_plot_init(plot_nr);

main_data = get(gcf,'UserData');

sim_active_tmp       = main_data.sim_active;
main_data.sim_active = 0;
set(gcf,'UserData',main_data);

if (plot_nr == 1)
    tag_axes                                  = 'demo_predictor_axes_top';
    set(gcf,'CurrentAxes',findobj('Tag',tag_axes));
    plot_method                               = main_data.axes_top.plot_method;
    main_data.axes_top.index                  = 0;
    main_data.axes_top.plot_method_changed    = 0;
else
    tag_axes                                  = 'demo_predictor_axes_bottom';
    set(gcf,'CurrentAxes',findobj('Tag',tag_axes)); 
    plot_method                               = main_data.axes_bottom.plot_method;
    main_data.axes_bottom.index               = 0;
    main_data.axes_bottom.plot_method_changed = 0;
end;

handle_1 = 0;
handle_2 = 0;

switch plot_method
    
    case 'pred_err'                       
        cla;
        handle_1 = plot([-2 -1],[0 0],'r','LineWidth',1,'EraseMode','none');
        max_abs = max(abs(main_data.signals.x));
        axis([0 length(main_data.signals.x)/main_data.f_s+eps -1.1*max_abs-eps 1.1*max_abs+eps]);
        grid on;
        legend('Predictor error signal');
        xlabel('Time in seconds'); 
        ylabel('Amplitude');
        drawnow;    
    
    case 'imp_res'        
        cla;        
        handle_1(1) = patch([-0.4 0.4 0.4 -0.4],[0 0 main_data.predictor.h(1) main_data.predictor.h(1)],'b');
        set(handle_1(1),'EraseMode','xor');
        for k = 1:main_data.predictor.length
            handle_1(k+1) = patch([k-0.4 k+0.4 k+0.4 k-0.4],[0 0 0.08 0.08],'r');
            set(handle_1(k+1),'EraseMode','xor');
        end;                         
        axis([-1 length(main_data.predictor.h) -2.5 2.5]);
        grid on;  
        legend('Predictor error filter');
        xlabel('Coefficient index'); 
        ylabel('Amplitude');
    
    case 'tf_ana'        
        cla;  
        [spec f t] = specgram(main_data.signals.x,512,main_data.f_s,hanning(512),512-64);
        imagesc(t,f/1000,20*log10(abs(spec)+eps));
        axis xy;                
        handle_1 = line([-1 -1],[0 main_data.f_s]);
        set(handle_1,'Color','k');
        set(handle_1,'LineWidth',2);
        set(handle_1,'EraseMode','xor');                        
        grid on;  
        xlabel('Time in seconds');
        ylabel('Frequency in kHz')

    case 't_ana'        
        cla;  
        max_abs = max(abs(main_data.signals.x));
        t = (0:(length(main_data.signals.x)-1)) / main_data.f_s;
        plot(t,main_data.signals.x,'LineWidth',1);
        axis([0 length(main_data.signals.x)/main_data.f_s+eps -1.1*max_abs-eps 1.1*max_abs+eps])                
        handle_1 = line([-1 -1],[-1.2*max_abs-eps 1.2*max_abs+eps]);
        set(handle_1,'Color','k');
        set(handle_1,'LineWidth',2);
        set(handle_1,'EraseMode','xor');                        
        grid on;  
        xlabel('Time in seconds');              
        
    case 'spec_env'                       
        cla;
        spec_sig = 20*log10(abs(fft(main_data.predictor.x_ana.*main_data.predictor.h_ana,main_data.predictor.n_fft)+eps));
        spec_sig = spec_sig(1:main_data.predictor.n_fft/2+1);
        spec_inv_pred = freqz(main_data.predictor.gain,main_data.predictor.h,main_data.predictor.n_fft,'whole');
        spec_inv_pred = 20*log10(abs(spec_inv_pred(1:main_data.predictor.n_fft/2+1))+eps);
        x_f  = (0:main_data.predictor.n_fft/2) / main_data.predictor.n_fft * main_data.f_s;
        handle_temp = plot(x_f,spec_sig,'b',x_f,spec_inv_pred,'r','LineWidth',2,'EraseMode','xor');
        handle_1 = handle_temp(1);
        handle_2 = handle_temp(2);
        axis([0 main_data.f_s/2 -70 40]);
        grid on;
        legend('Short-term spectrum','Inverse predictor error filter');
        xlabel('Frequency in Hz');
        ylabel('dB');        
        
end;

drawnow;

if (plot_nr == 1)
    main_data.axes_top.plot_handle_1 = handle_1;
    main_data.axes_top.plot_handle_2 = handle_2;
else
    main_data.axes_bottom.plot_handle_1 = handle_1;
    main_data.axes_bottom.plot_handle_2 = handle_2;    
end;

set(gca,'Tag',tag_axes);


main_data.sim_active = sim_active_tmp;
set(gcf,'UserData',main_data);